%{
/* need this for the call to atof() below */
#include <math.h>
#include <stdio.h>

FILE *fic;


%}

PLUS        [\+]
MINUS       [\-]
TIMES       [\*]
BY          [/]
ASSIGN      :=
BINARYOP    {PLUS}|{MINUS}|{TIMES}|{BY}|{ASSIGN}
SEPARATOR   [,:;\.]
PROGRAM     [Pp][Rr][Oo][Gg][Rr][Aa][Mm]
VAR         [Vv][Aa][Rr]
IF          [Ii][Ff]
THEN        [Tt][Hh][Ee][Nn]
ELSE        [Ee][Ll][Ss][Ee]
BEGIN       [Bb][Ee][Gg][Ii][Nn]
END         [Ee][Nn][Dd]
WHILE       [Ww][Hh][Ii][Ll][Ee]
FOR         [Ff][Oo][Rr]
DO          [Dd][Oo]
TO          [Tt][Oo]
FUNCTION    [Ff][Uu][Nn][Cc][Tt][Ii][Oo][Nn]
PROCEDURE   [Pp][Rr][Oo][Cc][Ee][Dd][Uu][Rr][Ee]
LETTER      [A-Za-z]
DIGIT       [0-9]
ID          {LETTER}({LETTER}|{DIGIT})*
INTEGER     ({PLUS}|{MINUS})?{DIGIT}+
REAL        {INTEGER}(\.({DIGIT})*)?([eE]{INTEGER})?
COMMENT     "{"[^}\n]*"}"
%%

{INTEGER}   {
            printf( "An integer: %s (%d)\n", yytext,
                    atoi( yytext ) );
            fprintf(fic, "%d", atoi(yytext));
            }

{REAL}      {
            printf( "A float: %s (%g)\n", yytext,
                    atof( yytext ) );
            fprintf(fic, "%g", atof(yytext));
            }

{IF}        convert_IF();

{THEN}      convert_THEN();

{ELSE}      convert_ELSE();

{BEGIN}     convert_BEGIN();

{END}       convert_END();

{VAR}       convert_VAR();

{FOR}       convert_FOR();

{DO}        convert_DO();

{TO}        convert_TO();

{WHILE}     convert_WHILE();

{PROCEDURE} convert_PROCEDURE();

{FUNCTION}  convert_FUNCTION();

{PROGRAM}   convert_PROGRAM();

{ID}                        {        
            printf( "An identifier: %s\n", yytext );
            fprintf(fic, "%s", yytext );
            }

{SEPARATOR} {
           printf( "A separator: %s\n", yytext );
           fprintf(fic, "%s", yytext );
           }

{BINARYOP}   {
           printf( "A binary operator: %s\n", yytext );
           fprintf(fic, "%s", yytext );
           }

{COMMENT}     {
                  printf( "A comment : %s\n", yytext );
                  fprintf(fic, "%s", yytext );
           }

^[ \t]+          fprintf(fic, "%s", yytext );
[ \t]+           fprintf(fic, "%s", " ");
[\n]+            fprintf(fic, "%s", "\n");



.           printf( "Unrecognized character: %s\n", yytext );

%%

keyword_message() { printf( "A keyword: %s\n", yytext );}

convert_IF() { keyword_message(); fprintf(fic, "%s", "SI"); }
convert_THEN() { keyword_message(); fprintf(fic, "%s", "ALORS"); }
convert_ELSE() { keyword_message(); fprintf(fic, "%s", "SINON"); }
convert_BEGIN() { keyword_message(); fprintf(fic, "%s", "DEBUT") ; }
convert_END() { keyword_message(); fprintf(fic, "%s", "FIN") ; }
convert_VAR() { keyword_message(); fprintf(fic, "%s", "VAR") ; }
convert_FOR() { keyword_message(); fprintf(fic, "%s", "POUR") ; }
convert_DO() { keyword_message(); fprintf(fic, "%s", "FAIRE") ; }
convert_TO() { keyword_message(); fprintf(fic, "%s", "A") ; }
convert_WHILE() { keyword_message(); fprintf(fic, "%s", "TANT QUE") ; }
convert_PROCEDURE() { keyword_message(); fprintf(fic, "%s", "PROCEDURE") ; }
convert_FUNCTION() { keyword_message(); fprintf(fic, "%s", "FONCTION") ; }
convert_PROGRAM() { keyword_message(); fprintf(fic, "%s", "PROGRAMME") ; }




int main() {

     fic = fopen("/tmp/pascal","w");
     
     yylex();

     fclose(fic);
     return 0;
}



